@@ -15,11 +15,17 @@ def _sanitise(
         bboxes: T,
         labels: T,
         convert_fn: Callable[..., T],
+        shape_fn: Callable[[T], Tuple[int, ...]],
         reshape_fn: Callable[[T, Tuple[int, ...]], T],
 ) -> Tuple[T, T, T]:
     """
-    Try to convert inputs to the expected format.
+    Try to convert input to the expected format.
     """
+    if len(shape_fn(image)) != 3:
+        raise ValueError(
+            "Input image must have 3 dimensions, i.e., "
+            "(height, width, num_channels)."
+        )
     image = convert_fn(image)
     bboxes = reshape_fn(convert_fn(bboxes), (-1, 4))
     labels = convert_fn(labels)
@@ -60,12 +66,10 @@ def _affine_transform(
     labels: [0, 1, 0, ...]
     """
     image, bboxes, labels = _sanitise(
-        image, bboxes, labels, convert_fn, reshape_fn
+        image, bboxes, labels, convert_fn, shape_fn, reshape_fn
     )
 
     image_shape = shape_fn(image)
-    assert len(image_shape) == 3
-
     height, width = int(image_shape[0]), int(image_shape[1])
     h_mod, w_mod = height % 2, width % 2
     num_channels = int(image_shape[2])
@@ -198,17 +202,17 @@ def _affine_transform(
 
 
 def _get_flip_left_right_mats(
-    convert_fn: Callable[..., T]
+        convert_fn: Callable[..., T]
 ) -> Tuple[T, T]:
     image_dest_flip_lr_mat = convert_fn([
-        [convert_fn(-1), convert_fn(0), convert_fn(0)],
-        [convert_fn(0), convert_fn(1), convert_fn(0)],
-        [convert_fn(0), convert_fn(0), convert_fn(1)]
+        [-1, 0, 0],
+        [0, 1, 0],
+        [0, 0, 1]
     ])
     bboxes_flip_lr_mat = convert_fn([
-        [convert_fn(-1), convert_fn(0), convert_fn(0)],
-        [convert_fn(0), convert_fn(1), convert_fn(0)],
-        [convert_fn(0), convert_fn(0), convert_fn(1)]
+        [-1, 0, 0],
+        [0, 1, 0],
+        [0, 0, 1]
     ])
     return image_dest_flip_lr_mat, bboxes_flip_lr_mat
 
@@ -258,17 +262,17 @@ def _flip_left_right(
 
 
 def _get_flip_up_down_mats(
-    convert_fn: Callable[..., T]
+        convert_fn: Callable[..., T]
 ) -> Tuple[T, T]:
     image_dest_flip_ud_mat = convert_fn([
-        [convert_fn(1), convert_fn(0), convert_fn(0)],
-        [convert_fn(0), convert_fn(-1), convert_fn(0)],
-        [convert_fn(0), convert_fn(0), convert_fn(1)]
+        [1, 0, 0],
+        [0, -1, 0],
+        [0, 0, 1]
     ])
     bboxes_flip_ud_mat = convert_fn([
-        [convert_fn(1), convert_fn(0), convert_fn(0)],
-        [convert_fn(0), convert_fn(-1), convert_fn(0)],
-        [convert_fn(0), convert_fn(0), convert_fn(1)]
+        [1, 0, 0],
+        [0, -1, 0],
+        [0, 0, 1]
     ])
     return image_dest_flip_ud_mat, bboxes_flip_ud_mat
 
@@ -372,7 +376,7 @@ def _rotate(
     image: [h, w, c]
     bboxes: [[top_left_x, top_left_y, width, height], ...]
     labels: [0, 1, 0, ...]
-    angle_deg: goes anti-clockwise.
+    angle_deg: positive means anti-clockwise.
     """
     image_dest_rot_mat, bboxes_rot_mat = _get_rotate_mats(
         angle_deg, convert_fn, cos_fn, sin_fn
@@ -441,7 +445,7 @@ def _shear(
     image: [h, w, c]
     bboxes: [[top_left_x, top_left_y, width, height], ...]
     labels: [0, 1, 0, ...]
-    angle_deg: goes anti-clockwise, where abs(angle_deg) must be < 90.
+    angle_deg: positive means anti-clockwise, where abs(angle_deg) must be < 90.
     """
     image_dest_shear_mat, bboxes_shear_mat = _get_shear_mats(
         angle_deg, convert_fn, tan_fn
@@ -506,8 +510,8 @@ def _translate(
     image: [h, w, c]
     bboxes: [[top_left_x, top_left_y, width, height], ...]
     labels: [0, 1, 0, ...]
-    translate_height: in range [-image_height + 1: image_height - 1]
-    translate_width: in range [-image_width + 1: image_width - 1]
+    translate_height: in range (-image_height, image_height)
+    translate_width: in range (-image_width, image_width)
     """
     image_dest_translate_mat, bboxes_translate_mat = _get_translate_mats(
         translate_height, translate_width, convert_fn
@@ -605,16 +609,13 @@ def _crop(
     image: [h, w, c]
     bboxes: [[top_left_x, top_left_y, width, height], ...]
     labels: [0, 1, 0, ...]
-    offset_height: in range [0, image_height - 1]
-    offset_width: in range [0, image_width - 1]
+    offset_height: in range [0, image_height)
+    offset_width: in range [0, image_width)
     """
     image, bboxes, labels = _sanitise(
-        image, bboxes, labels, convert_fn, reshape_fn
+        image, bboxes, labels, convert_fn, shape_fn, reshape_fn
     )
 
-    image_shape = shape_fn(image)
-    assert len(image_shape) == 3
-
     top = offset_height
     left = offset_width
     bottom = top + cropped_image_height
@@ -672,12 +673,10 @@ def _resize(
     dest_size: (height, width)
     """
     image, bboxes, labels = _sanitise(
-        image, bboxes, labels, convert_fn, reshape_fn
+        image, bboxes, labels, convert_fn, shape_fn, reshape_fn
     )
 
     image_shape = shape_fn(image)
-    assert len(image_shape) == 3
-
     if image_shape[0] == dest_size[0] and image_shape[1] == dest_size[1]:
         return image, bboxes, labels
 
