@@ -246,11 +246,15 @@ class TFRandomTransform:
             tf_fn: Callable[..., Tuple[tf.Tensor, tf.Tensor, tf.Tensor]],
             probability: float,
             seed: Optional[int],
+            name: str,
+            is_affine: bool
     ) -> None:
         self._tf_fn = tf_fn
         self.probability = probability
         self._rng = tf.random.Generator.from_seed(seed) if seed is not None \
             else tf.random.Generator.from_non_deterministic_state()
+        self.name = name
+        self.is_affine = is_affine
 
     def _rand_fn(self, shape: Tuple[int, ...] = ()) -> tf.Tensor:
         return self._rng.uniform(shape=shape)
@@ -288,7 +292,15 @@ class TFCombineAffine(TFRandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
-        super().__init__(_tf_affine_transform, probability, seed)
+        not_affine_trans = filter(lambda t: not t.is_affine, transforms)
+        if not_affine_trans:
+            raise ValueError(
+                f"Non-affine transforms cannot be included in TFCombineAffine: "
+                f"{[t.name for t in not_affine_trans]}"
+            )
+        super().__init__(
+            _tf_affine_transform, probability, seed, "TFCombineAffine", True
+        )
         self._transforms = transforms
         self._identity_mat = tf.expand_dims(tf.constant([
             [1.0, 0.0, 0.0], [0.0, 1.0, 0.0], [0.0, 0.0, 1.0]
@@ -344,7 +356,9 @@ class TFRandomFlipLeftRight(TFRandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
-        super().__init__(tf_flip_left_right, probability, seed)
+        super().__init__(
+            tf_flip_left_right, probability, seed, "TFRandomFlipLeftRight", True
+        )
 
     def get_mats(
             self,
@@ -371,7 +385,9 @@ class TFRandomFlipUpDown(TFRandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
-        super().__init__(tf_flip_up_down, probability, seed)
+        super().__init__(
+            tf_flip_up_down, probability, seed, "TFRandomFlipUpDown", True
+        )
 
     def get_mats(
             self,
@@ -400,7 +416,7 @@ class TFRandomRotate(TFRandomTransform):
             seed: Optional[int] = None
     ) -> None:
         _check_input_range(angle_deg_range, None, "angle_deg_range")
-        super().__init__(tf_rotate, probability, seed)
+        super().__init__(tf_rotate, probability, seed, "TFRandomRotate", True)
         self.angle_deg_range = angle_deg_range
 
     def _get_angle_deg(self, rand_fn: Callable[..., tf.Tensor]) -> tf.Tensor:
@@ -438,7 +454,7 @@ class TFRandomShear(TFRandomTransform):
             seed: Optional[int] = None
     ) -> None:
         _check_input_range(angle_deg_range, (-90.0, 90.0), "angle_deg_range")
-        super().__init__(tf_shear, probability, seed)
+        super().__init__(tf_shear, probability, seed, "TFRandomShear", True)
         self.angle_deg_range = angle_deg_range
 
     def _get_angle_deg(self, rand_fn: Callable[..., tf.Tensor]) -> tf.Tensor:
@@ -484,7 +500,9 @@ class TFRandomTranslate(TFRandomTransform):
             translate_width_fraction_range, (-1.0, 1.0),
             "translate_width_fraction_range"
         )
-        super().__init__(tf_translate, probability, seed)
+        super().__init__(
+            tf_translate, probability, seed, "TFRandomTranslate", True
+        )
         self.translate_height_fraction_range = translate_height_fraction_range
         self.translate_width_fraction_range = translate_width_fraction_range
 
@@ -543,7 +561,7 @@ class TFRandomCrop(TFRandomTransform):
         _check_input_range(
             crop_width_fraction_range, (0.0, 1.0), "crop_width_fraction_range"
         )
-        super().__init__(tf_crop, probability, seed)
+        super().__init__(tf_crop, probability, seed, "TFRandomCrop", False)
         self.crop_height_fraction_range = crop_height_fraction_range
         self.crop_width_fraction_range = crop_width_fraction_range
 
@@ -573,6 +591,8 @@ class TFResize:
 
     def __init__(self, dest_size: Tuple[int, int]) -> None:
         self.dest_size = dest_size
+        self.name = "TFResize"
+        self.is_affine = False
 
     def __call__(
             self,
